"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const jwt = require("jsonwebtoken");
const DataEncryptor_1 = require("../../utilities/DataEncryptor/DataEncryptor");
const TokenValidator_1 = require("../../adapters/TokenValidator/TokenValidator");
class AuthenticateAdminService {
    static authAdmin(reqBody, AdminModel) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { username, password } = reqBody;
            const adminRow = yield AdminModel.findOne({ where: { username } });
            let token = {};
            if (adminRow !== null) {
                token = yield AuthenticateAdminService.checkIfPasswordsMatch(password, adminRow);
            }
            return token;
        });
    }
    static checkIfPasswordsMatch(plainPassword, adminRow) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const isPasswordsMatch = yield DataEncryptor_1.DataEncryptor.compare(plainPassword, adminRow.password);
            let token = {};
            if (isPasswordsMatch) {
                const admin = AuthenticateAdminService.removePasswordPropFromAdminRow(adminRow);
                token = { token: AuthenticateAdminService.createToken(admin) };
            }
            return token;
        });
    }
    static removePasswordPropFromAdminRow(adminRow) {
        const _a = adminRow.dataValues, { password } = _a, admin = tslib_1.__rest(_a, ["password"]);
        return admin;
    }
    static createToken(admin) {
        const token = jwt.sign({ admin }, 'expressadminarea');
        return token;
    }
    static verifyToken(token, AdminModel) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let isAdminExists = { status: 404, message: 'Not Found', body: false };
            try {
                const username = (yield TokenValidator_1.TokenValidator.verify(token)).admin.username;
                const admin = yield AdminModel.findOne({ where: { username } });
                if (admin !== null) {
                    isAdminExists = { status: 200, message: 'Ok', body: true };
                }
            }
            catch (e) {
                isAdminExists = { status: 500, message: 'Internal Server Error', body: false };
            }
            return isAdminExists;
        });
    }
}
exports.AuthenticateAdminService = AuthenticateAdminService;
//# sourceMappingURL=AuthenticateAdminService.js.map