"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
class DBTablesService {
    static getTables(dbModels) {
        let dbTables = [];
        if (Object.prototype.toString.call(dbModels) === '[object Object]') {
            dbTables = Object.keys(dbModels);
        }
        return dbTables;
    }
    static getTablesFieldNames(dbModel) {
        const modelRawAttributes = new dbModel().rawAttributes;
        const modelFieldNames = Object.keys(modelRawAttributes);
        return modelFieldNames;
    }
    static getTableRows(model) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let columns = null;
            try {
                columns = yield model.scope('expressAdminArea').findAll();
            }
            catch (_e) {
                columns = { message: 'No Content', status: 204 };
            }
            return columns;
        });
    }
    static getTableRowByPk(reqParams, dbModel) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let row = { message: 'No Content', status: 204 };
            try {
                const rowPk = reqParams.pk;
                const model = dbModel;
                row = (yield model.scope('expressAdminArea').findByPk(rowPk)) || row;
            }
            catch (_e) {
                row = { message: 'Bad Request', status: 400 };
            }
            return row;
        });
    }
    static createRow(reqBody, dbModel) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let newRow = {};
            try {
                newRow = yield dbModel.create(reqBody);
            }
            catch (_e) {
                newRow = { message: 'Bad Request', status: 400 };
            }
            return newRow;
        });
    }
    static updateRow(reqBody, dbModel) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let updatedRow = { message: 'No Content', status: 204 };
            try {
                let rowFound = yield dbModel.findByPk(reqBody.pk);
                rowFound = DBTablesService.updateRowFields(rowFound, reqBody);
                yield rowFound.save();
            }
            catch (error) {
                console.log(error);
                updatedRow = { message: 'Bad Request', status: 400 };
            }
            return updatedRow;
        });
    }
    static updateRowFields(row, reqBody) {
        row = row;
        for (let field in reqBody) {
            row[field] = reqBody[field];
        }
        return row;
    }
    static deleteRow(reqBody, dbModel) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let response = { message: 'OK', status: 200 };
            try {
                yield dbModel.destroy({ where: { id: reqBody.pk } });
            }
            catch (e) {
                response = { message: 'Bad Request', status: 400 };
            }
            return response;
        });
    }
}
exports.DBTablesService = DBTablesService;
//# sourceMappingURL=DBTablesService.js.map